/*******************************************************************************
* File Name: Display.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Display.h"


/*******************************************************************************
* Function Name: Display_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Display_Write(uint8 value) 
{
    uint8 staticBits = Display_DR & ~Display_MASK;
    Display_DR = staticBits | ((value << Display_SHIFT) & Display_MASK);
}


/*******************************************************************************
* Function Name: Display_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Display_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Display_0, mode);
}


/*******************************************************************************
* Function Name: Display_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Display_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Display_Read(void) 
{
    return (Display_PS & Display_MASK) >> Display_SHIFT;
}


/*******************************************************************************
* Function Name: Display_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Display_ReadDataReg(void) 
{
    return (Display_DR & Display_MASK) >> Display_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Display_INTSTAT) 

    /*******************************************************************************
    * Function Name: Display_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Display_ClearInterrupt(void) 
    {
        return (Display_INTSTAT & Display_MASK) >> Display_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
